package com.yihu.ehr.profile.controller.profile;

import com.fasterxml.jackson.databind.ObjectMapper;
import com.yihu.ehr.constants.ApiVersion;
import com.yihu.ehr.constants.ServiceApi;
import com.yihu.ehr.controller.EnvelopRestEndPoint;
import com.yihu.ehr.profile.model.InspectionInfo;
import com.yihu.ehr.profile.service.ProfileCDAService;
import com.yihu.ehr.profile.service.ProfileInspectionService;
import com.yihu.ehr.util.rest.Envelop;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;
import java.util.Map;

/**
 * EndPoint - 检查检验
 * Created by progr1mmer on 2018/3/13.
 */
@RestController
@RequestMapping(value = ApiVersion.Version1_0, produces = MediaType.APPLICATION_JSON_UTF8_VALUE)
@Api(value = "ProfileInspectionEndPoint", description = "检查检验", tags = {"档案影像服务 - 检查检验"})
public class ProfileInspectionEndPoint extends EnvelopRestEndPoint {

    @Autowired
    private ProfileInspectionService profileInspectionService;
    @Autowired
    private ProfileCDAService profileCDAService;

    @ApiOperation("检查检验记录 - 上饶APP")
    @RequestMapping(value = ServiceApi.Profiles.InspectionRecords, method = RequestMethod.GET)
    public List inspectionRecords(
            @ApiParam(name = "demographic_id", value = "身份证号", required = true, defaultValue = "362301195002141528")
            @RequestParam(value = "demographic_id") String demographic_id,
            @ApiParam(name = "filter", value = "健康问题health_problem?hpCode（不传默认查找所有）")
            @RequestParam(value = "filter", required = false) String filter,
            @ApiParam(name = "date", value = "时间 {'start':'2018-03-12T12:00:00Z','end':'2018-03-15T12:00:00Z'}")
            @RequestParam(value = "date", required = false) String date,
            @ApiParam(name = "searchParam", value = "搜索条件")
            @RequestParam(value = "searchParam", required = false) String searchParam) throws Exception {
        return profileInspectionService.inspectionRecords(demographic_id, filter, date, searchParam);
    }

    /**
     * 检验有子项结果，不能在此接口直接返回
     * 故需要调用其他接口获取统计数据
     * @param demographic_id
     * @param table
     * @return
     * @throws Exception
     */
    @ApiOperation("检查检验记录统计 - 档案浏览器")
    @RequestMapping(value = ServiceApi.Profiles.InspectionStatistics, method = RequestMethod.GET)
    public List<InspectionInfo> inspectionStatistics(
            @ApiParam(name = "demographic_id", value = "身份证号", required = true, defaultValue = "362301195002141528")
            @RequestParam(value = "demographic_id") String demographic_id,
            @ApiParam(name = "table", required = true, value = "HDSD00_79 - 检查， HDSD00_77 - 检验")
            @RequestParam(value = "table") String table) throws Exception {
        return profileInspectionService.inspectionStatistics(demographic_id, table);
    }

    @ApiOperation("检查检验记录子项详情（某次检验记录） - 档案浏览器")
    @RequestMapping(value = ServiceApi.Profiles.InspectionStatisticsOneSub, method = RequestMethod.GET)
    public Map<String, String> inspectionStatisticsOneSub(
            @ApiParam(name = "profile_id", value = "档案ID", required = true, defaultValue = "49236052X_17022473_1503229954000$HDSD00_77$3")
            @RequestParam(value = "profile_id") String profile_id) throws Exception {
        return profileInspectionService.inspectionStatisticsOneSub(profile_id);
    }

    @ApiOperation("检查检验记录子项详情（相关检验全部记录） - 档案浏览器")
    @RequestMapping(value = ServiceApi.Profiles.InspectionStatisticsAllSub, method = RequestMethod.GET)
    public Map<String, Map<String, Integer>> inspectionStatisticsAllSub(
            @ApiParam(name = "demographic_id", value = "身份证号码", required = true, defaultValue = "9d2970b8-dac5-40bb-816d-d3e841a29afc")
            @RequestParam(value = "demographic_id") String demographic_id,
            @ApiParam(name = "name", required = true, value = "检验名称")
            @RequestParam(value = "name") String name) throws Exception {
        return profileInspectionService.inspectionStatisticsAllSub(demographic_id, name);
    }


    @ApiOperation("检查检验记录 - 【区域检验平台】")
    @RequestMapping(value = "/exam/list", method = RequestMethod.GET)
    public Envelop areaInspectionRecords(
            @ApiParam(name = "orgCode", value = "机构编码")
            @RequestParam(value = "orgCode", required = false) String orgCode,
            @ApiParam(name = "orgDept", value = "科室编码（不传默认查找所有）")
            @RequestParam(value = "orgDept", required = false) String orgDept,
            @ApiParam(name = "type", value = "检查：HDSD00_79,检验：HDSD00_77（不传默认查找所有）")
            @RequestParam(value = "type", required = false) String type,
            @ApiParam(name = "patientName", value = "患者姓名")
            @RequestParam(value = "patientName", required = false) String patientName,
            @ApiParam(name = "startDate", value = "起始时间 ",defaultValue = "2018-06-12 12:00:00")
            @RequestParam(value = "startDate", required = false) String startDate,
            @ApiParam(name = "endDate", value = "终止时间", required = true, defaultValue = "2018-09-12 12:00:00")
            @RequestParam(value = "endDate") String endDate,
            @ApiParam(name = "page", value = "页码", required = true,defaultValue = "1")
            @RequestParam(value = "page") Integer page,
            @ApiParam(name = "size", value = "分页大小", required = true,defaultValue = "20")
            @RequestParam(value = "size") Integer size) throws Exception {

        List list = profileInspectionService.areaInspectionRecords(orgCode, orgDept, type, patientName, startDate, endDate);
//        String demo = "[{\"patientName\":\"陈玲佩\",\"itemName\":\"结核抗体\",\"patientSex\":\"1\",\"examDate\":\"2018-08-28T08:44:13Z\",\"profileId\":\"49229004X_273129_1535944747000$HDSD00_77$8\",\"examiner\":\"蒙琼琳\",\"patientAge\":\"56岁\",\"dept\":\"检验科\",\"type\":null},{\"patientName\":\"周旭瑜\",\"itemName\":\"找抗酸杆菌3\",\"patientSex\":\"1\",\"examDate\":\"2018-08-30T08:54:16Z\",\"profileId\":\"49229004X_273129_1535944747000$HDSD00_77$7\",\"examiner\":\"周旭瑜\",\"patientAge\":\"56岁\",\"dept\":\"检验科\",\"type\":null}]";
//        ObjectMapper objectMapper = new ObjectMapper();
//       List list = objectMapper.readValue(demo,List.class);
        return success(list);

    }

    @ApiOperation("检验档案详情查询 - 【区域检验平台】")
    @RequestMapping(value = "/exam/detail", method = RequestMethod.GET)
    public Envelop areaInspectionDetail(
            @ApiParam(name = "profileId", value = "检验档案唯一标识")
            @RequestParam(value = "profileId", required = true) String profileId) throws Exception {

        Map<String, Object> map = profileCDAService.getInspectionPartData(profileId,true,null);
        return success(map);

    }

}
